Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2490)

Unified Diff: chrome/browser/renderer_host/browser_render_process_host.cc

Issue 6338002: net: Remove typedef net::URLRequestContext URLRequestContext; (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: for real Created 9 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/renderer_host/browser_render_process_host.cc
diff --git a/chrome/browser/renderer_host/browser_render_process_host.cc b/chrome/browser/renderer_host/browser_render_process_host.cc
index 3750dd3f9f079fe3959a2b9f04d47429ef4a98ee..82caa115a24ff81b034a3690ee2169a625ba56d9 100644
--- a/chrome/browser/renderer_host/browser_render_process_host.cc
+++ b/chrome/browser/renderer_host/browser_render_process_host.cc
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -229,7 +229,7 @@ class VisitedLinkUpdater {
namespace {
// Helper class that we pass to ResourceMessageFilter so that it can find the
// right URLRequestContext for a request.
class RendererURLRequestContextOverride
: public ResourceMessageFilter::URLRequestContextOverride {
public:
@@ -238,7 +238,7 @@ class RendererURLRequestContextOverride
media_request_context_(profile->GetRequestContextForMedia()) {
}
- virtual URLRequestContext* GetRequestContext(
+ virtual net::URLRequestContext* GetRequestContext(
uint32 request_id, ResourceType::Type resource_type) {
URLRequestContextGetter* request_context = request_context_;
// If the request has resource type of ResourceType::MEDIA, we use a request
@@ -229,7 +229,7 @@ class VisitedLinkUpdater {
namespace {
// Helper class that we pass to ResourceMessageFilter so that it can find the
-// right URLRequestContext for a request.
+// right net::URLRequestContext for a request.
class RendererURLRequestContextOverride
: public ResourceMessageFilter::URLRequestContextOverride {

Powered by Google App Engine
This is Rietveld 408576698